#
# spec file for package sharutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sharutils
Version:        4.15.2
Release:        10.1
Summary:        GNU shar utilities
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://www.gnu.org/software/sharutils/
Source0:        https://ftp.gnu.org/gnu/sharutils/sharutils-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/sharutils/sharutils-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Patch0:         sharutils-testsuite.diff
Patch1:         sharutils-CVE-2018-1000097-fix_buffer_overflow.patch
Patch2:         gnulib-libio.patch
Patch3:         sharutils-4.14.2-Pass-compilation-with-Werror-format-security.patch
BuildRequires:  libopenssl-devel
BuildRequires:  xz
Requires(pre):  %{install_info_prereq}
Requires(pre):  coreutils
Provides:       sharutil = %{version}
Obsoletes:      sharutil < %{version}

%description
This is the set of GNU shar utilities.

shar makes shell archives out of many files, preparing them for
transmission by electronic mail services.  Use unshar to unpack shell
archives after reception.

uuencode prepares a file for transmission over an electronic channel
which ignores or otherwise mangles the eight bit (high order bit) of
bytes.	uudecode does the converse transformation.

%{?lang_package}

%prep
%setup -q
%patch -P 0
%patch -P 1
%patch -P 2 -p1
%patch -P 3 -p1
chmod +w src/scripts.x

%build
mkdir -p ../bin
ln -snf /bin/true ../bin/compress
PATH=$PWD/../bin:$PATH
%global optflags %{optflags} -fcommon -std=gnu11
%configure \
	--with-openssl

%make_build

%check
%make_build check

%install
%make_install
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files lang -f %{name}.lang

%files
%doc README NEWS THANKS
%license COPYING
%{_bindir}/*
%{_infodir}/*.gz
%{_mandir}/*/*.gz

%changelog
* Sat Apr  5 2025 Friedrich Haubensak <hsk17@mail.de>
- add -std=gnu11 to CFLAGS to fix gcc15 compile time error, and to
  still allow build on Leap 15.6
* Tue May 14 2024 pgajdos@suse.com
- fix build with gcc14
- modified patches
  %% sharutils-CVE-2018-1000097-fix_buffer_overflow.patch
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Apr 20 2022 Dirk Müller <dmueller@suse.com>
- add sharutils-4.14.2-Pass-compilation-with-Werror-format-security.patch
* Fri Jan 31 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Tue Jan 21 2020 Christian Vögl <cvoegl@suse.de>
- Add -fcommon to optflags. This fixes (boo#1160292), and can be
  removed if upstream releases a version which compiles with
  - fno-common
* Thu Aug 29 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop mailx BuildRequires. The "sync directories over mail" feature
  has been removed in 4.11.1.
* Mon Aug  6 2018 schwab@suse.de
- gnulib-libio.patch: Update gnulib for libio.h removal
- Use %%license for COPYING
* Tue Mar 13 2018 pth@suse.de
- Add sharutils-CVE-2018-1000097-fix_buffer_overflow.patch to fix
  a possibility to overflow the stack (bsc#1085004, CVE-2018-1000097).
* Fri Jun 19 2015 astieger@suse.com
- update to 4.15.2:
  * updates to fix cross platform build issues
  * fixed problem where contrived uuencoded file caused seg fault
* Sun May  3 2015 astieger@suse.com
- update to sharutils 4.15.1
  * gnulib updates to fix rare platform build issues
* Thu Feb 26 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg key
- Remove obsolete patches
  * sharutils-set_file_mode.diff
  * sharutils-mandir.patch
  * sharutils-stdio.in.patch
- Enable openssl support
- Remove bcond and allways build with mailx
- Update lang package macros
- Update to Version 4.15
  * shar will no longer choke on 64 bit windows
  * unshar has a compiler warning fix
  * Happy 2015 copyright
  * PO file updates
- Version 4.14.2
  * translation updates
  * use ftello, fseeko and fflush
  * augment copyright marks in shar.c and shar-std.def
  * Happy 2014 copyright dates
  * fix up man pages (use newer doc generation code)
- Version 4.14
  * documentation, obscure usage, FSF address
- Version 4.13.5
  * primarily, configuration cleanups.  Mostly for MinGW,
  but some others, too.
- Version 4.13.4
  * output file names may be encoded in the uuencoded file.
    By specifying '--encode' on the command line, the output
    file name will be base64 encoded in the uuencode file.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu May 31 2012 sweet_f_a@gmx.de
- remove useless automake dependency
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Jul 29 2011 aj@suse.de
- Recommends instead of require lang package.
* Thu Jul 28 2011 giecrilj@stegny.2a.pl
- create sharutils-lang
* Tue Jul 26 2011 pth@suse.de
- Update to 4.11.1. Changes since 2.6.3:
  4.11.1:
  * mail-files was completely broken and cannot be in use.  Removed.
    mailshar (its wrapper script) also remvoed.
  4.10:
  * test and handle clobber option correctly in generated scripts.
  4.9:
  * Fix up quoting some more in the shar script messages.
    Translators will not have to worry over shell quoting any more.
  4.7.1:
  * uudecode will not create output file names with trailing white space
  4.7:
  * fix a grammatical typo in doc/uuencode.1
  * relicense the product under GPL version 3.
- Remove unneeded dummy.diff.
- Prefix all patches with pacckage name.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Nov 19 2007 schwab@suse.de
- Fix packaging bug.
* Thu Nov 15 2007 schwab@suse.de
- Update to sharutils 4.6.3.
  * Recognize "end\r\n" as "end" as well as "end\n".
  * Avoid duplicate declarations of "readdir".
  * generate compress-dummy.1 from the dummy script at bootstrap time
* Mon May 15 2006 schwab@suse.de
- Update to sharutils 4.6.2.
  * uudecode.c(decode): make clear the name of the file causing problems
  * uudecode.c (O_BINARY): Define for all platforms.
  (decode): Always open with binary, where it matters.
  * uuencode.c [__CYGWIN__]: Include io.h for setmode.
  (O_BINARY): Define for all platforms.
  (main): Always open with binary, where it matters.
  (main) [__CYGWIN__]: Use setmode to make stdin binary.
  * src/shar.c(echo_status): new - report status in consistent fashion.
  (throughout): remove many strings to scripts.def file.
  * src/scripts.def: add many new entries and alphabetize
  * tests/shar-1.ok: adjust to changes
  * tests/Makefile.am: add 'shar-3' test and a clean rule
  * tests/shar-3: new - test large multi part archive
  * tests/shar-1: delete varying text, not arbitrary lines from sample
  * tests/shar-2: remove unnecessary line removal
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 schwab@suse.de
- Update to sharutils 4.6.
* Thu Aug  4 2005 schwab@suse.de
- Update to sharutils 4.5.
* Mon Jul 25 2005 schwab@suse.de
- Update to sharutils 4.4.
* Mon Jun 27 2005 schwab@suse.de
- Update to sharutils 4.3.81.
* Sun May  1 2005 schwab@suse.de
- Update to sharutils 4.3.80.
* Wed Apr 27 2005 schwab@suse.de
- Update to sharutils 4.3.79.
* Tue Apr 19 2005 kukuk@suse.de
- Remove compress symlink [#78331]
* Mon Jan 24 2005 schwab@suse.de
- Update to sharutils 4.3.78.
* Wed Nov  3 2004 schwab@suse.de
- Fix buffer underrun [#46557].
* Mon Oct 25 2004 schwab@suse.de
- Fix another quoting bug.
* Fri Oct  8 2004 schwab@suse.de
- Update to sharutils 4.3.77.
* Thu Sep 30 2004 schwab@suse.de
- Properly quote filenames in generated shar output.
- Fix buffer overruns [#46557].
* Fri Aug 13 2004 schwab@suse.de
- Rename ja_JP.EUC.po to ja.po and fix encoding header [#43607].
* Mon May  3 2004 schwab@suse.de
- Better fix for last change.
* Tue Apr 20 2004 schwab@suse.de
- Fix arbitrary file name limit [#39122].
* Fri Mar  5 2004 schwab@suse.de
- Add /usr/bin/compress as %%ghost.
* Fri Dec 12 2003 schwab@suse.de
- Remove extra AC_LINK_FILES.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Mon Nov 18 2002 schwab@suse.de
- Add AM_GNU_GETTEXT_VERSION.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Wed Jul 10 2002 schwab@suse.de
- Remove last change, breaks POSIX conformance.
* Mon Jul  8 2002 ke@suse.de
- Fix uudecode file handling (FIFO, symlink, and  pipe output):
  CAN-2002-0178; make use of RHSA-2002:065-13.
* Tue Jul  2 2002 mls@suse.de
- removed mininews from neededforbuild, was only needed for uudeview
* Tue Jul  2 2002 max@suse.de
- Split off uudeview into a separate package.
* Mon Jun 24 2002 schwab@suse.de
- Fix last change.
* Mon Jun 24 2002 ke@suse.de
- compress-dummy.sh.in: Add this script and install a link 'compress'
  pointing to it; thus legacy shar files calling 'compress -d < ...'
  can succeed; cf. [# 16299].
- sharutils-compress.diff: Patch to install compress-dummy.sh.
- sharutils-printf.diff: Avoid embedded newlines in strings (xgettext
  warns about those strings).
* Fri Dec  7 2001 schwab@suse.de
- Run autoconf in uudeview.
- Fix provides.
* Mon Dec  4 2000 schwab@suse.de
- Use BuildRoot.
- Avoid `install -s' on non-binaries.
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Tue Oct 24 2000 schwab@suse.de
- Renamed from sharutil.
* Tue May 30 2000 schwab@suse.de
- mailshar: recognize `*.tgz' as compressed file
* Mon May 29 2000 max@suse.de
- changed use of Tk_Main to Tk_MainEx for compatibility with
  Tcl/Tk 8.3.
* Tue Jan 18 2000 schwab@suse.de
- /usr/{info,man} -> /usr/share/{info,man}
* Tue Jan  4 2000 schwab@suse.de
- Enable NLS
* Tue Jan  4 2000 schwab@suse.de
- Y2K fixes from sharutils 4.2.1
- Fix mktemp usage and quoting in mailshar
* Tue Oct 12 1999 ro@suse.de
- added tcld to neededforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Sep  8 1999 schwab@suse.de
- run "make check"
* Fri Aug 27 1999 schwab@suse.de
- specfile cleanup
- add mininews as neededforbuild
- fix shell expansion bug in uudeview configure script
* Fri Jul 17 1998 werner@suse.de
- Use mktemp
* Thu Jul 16 1998 werner@suse.de
- mailshar fix to remove already existing temp files
* Thu Feb  5 1998 florian@suse.de
- fix setting of mail program for mailshar
* Fri Oct 17 1997 ro@suse.de
- ready for autobuild
* Sun Jun 22 1997 florian@suse.de
- update to sharutil 4.2c
- update to uudeview 0.5.13
* Thu Jan  2 1997 florian@suse.de
  added additional source package uudeview
